==> arpes-1.1.0.tar.gz: arpes-1.1.0/docs/modules.md <==
# arpes

  -   - [arpes package](arpes)
        
          -   - [Subpackages](arpes#subpackages)
                
                  -   - [arpes.analysis package](arpes.analysis)
                        
                          - [Submodules](arpes.analysis#submodules)
                          - [Module
                            contents](arpes.analysis#module-contents)
                
                  -   - [arpes.corrections package](arpes.corrections)
                        
                          - [Submodules](arpes.corrections#submodules)
                          - [Module
                            contents](arpes.corrections#module-contents)
                
                  -   - [arpes.endstations package](arpes.endstations)
                        
                          - [Subpackages](arpes.endstations#subpackages)
                          - [Submodules](arpes.endstations#submodules)
                          - [Module
                            contents](arpes.endstations#module-arpes.endstations)
                
                  -   - [arpes.fits package](arpes.fits)
                        
                          - [Submodules](arpes.fits#submodules)
                          - [Module
                            contents](arpes.fits#module-contents)
                
                  -   - [arpes.laue package](arpes.laue)
                        
                          - [Module
                            contents](arpes.laue#module-arpes.laue)
                
                  -   - [arpes.models package](arpes.models)
                        
                          - [Submodules](arpes.models#submodules)
                          - [Module
                            contents](arpes.models#module-contents)
                
                  -   - [arpes.plotting package](arpes.plotting)
                        
                          - [Subpackages](arpes.plotting#subpackages)
                          - [Submodules](arpes.plotting#submodules)
                          - [Module
                            contents](arpes.plotting#module-contents)
                
                  -   - [arpes.preparation package](arpes.preparation)
                        
                          - [Submodules](arpes.preparation#submodules)
                          - [Module
                            contents](arpes.preparation#module-arpes.preparation)
                
                  -   - [arpes.utilities package](arpes.utilities)
                        
                          - [Subpackages](arpes.utilities#subpackages)
                          - [Submodules](arpes.utilities#submodules)
                          - [Module
                            contents](arpes.utilities#module-arpes.utilities)
        
          -   - [Submodules](arpes#submodules)
                
                  - [arpes.bootstrap module](arpes.bootstrap)
                  - [arpes.config module](arpes.config)
                  - [arpes.constants module](arpes.constants)
                  - [arpes.exceptions module](arpes.exceptions)
                  - [arpes.io module](arpes.io)
                  - [arpes.laser module](arpes.laser)
                  - [arpes.load\_pxt module](arpes.load_pxt)
                  - [arpes.materials module](arpes.materials)
                  - [arpes.optics module](arpes.optics)
                  - [arpes.pipeline module](arpes.pipeline)
                  - [arpes.pipelines module](arpes.pipelines)
                  - [arpes.provenance module](arpes.provenance)
                  - [arpes.repair module](arpes.repair)
                  - [arpes.typing module](arpes.typing)
                  - [arpes.widgets module](arpes.widgets)
                  - [arpes.xarray\_extensions
                    module](arpes.xarray_extensions)
                  - [arpes.xarray\_html\_repr
                    module](arpes.xarray_html_repr)
        
          - [Module contents](arpes#module-arpes)

==> arpes-2.1.0.tar.gz: arpes-2.1.0/docs/modules.md <==
# arpes

  -   - [arpes package](arpes)
        
          -   - [Subpackages](arpes#subpackages)
                
                  -   - [arpes.analysis package](arpes.analysis)
                        
                          - [Submodules](arpes.analysis#submodules)
                          - [Module
                            contents](arpes.analysis#module-arpes.analysis)
                
                  -   - [arpes.corrections package](arpes.corrections)
                        
                          - [Submodules](arpes.corrections#submodules)
                          - [Module
                            contents](arpes.corrections#module-arpes.corrections)
                
                  -   - [arpes.endstations package](arpes.endstations)
                        
                          - [Subpackages](arpes.endstations#subpackages)
                          - [Submodules](arpes.endstations#submodules)
                          - [Module
                            contents](arpes.endstations#module-arpes.endstations)
                
                  -   - [arpes.fits package](arpes.fits)
                        
                          - [Submodules](arpes.fits#submodules)
                          - [Module
                            contents](arpes.fits#module-arpes.fits)
                
                  -   - [arpes.laue package](arpes.laue)
                        
                          - [Module
                            contents](arpes.laue#module-arpes.laue)
                
                  -   - [arpes.models package](arpes.models)
                        
                          - [Submodules](arpes.models#submodules)
                          - [Module
                            contents](arpes.models#module-arpes.models)
                
                  -   - [arpes.plotting package](arpes.plotting)
                        
                          - [Subpackages](arpes.plotting#subpackages)
                          - [Submodules](arpes.plotting#submodules)
                          - [Module
                            contents](arpes.plotting#module-arpes.plotting)
                
                  -   - [arpes.preparation package](arpes.preparation)
                        
                          - [Submodules](arpes.preparation#submodules)
                          - [Module
                            contents](arpes.preparation#module-arpes.preparation)
                
                  -   - [arpes.utilities package](arpes.utilities)
                        
                          - [Subpackages](arpes.utilities#subpackages)
                          - [Submodules](arpes.utilities#submodules)
                          - [Module
                            contents](arpes.utilities#module-arpes.utilities)
        
          -   - [Submodules](arpes#submodules)
                
                  - [arpes.bootstrap module](arpes.bootstrap)
                  - [arpes.config module](arpes.config)
                  - [arpes.constants module](arpes.constants)
                  - [arpes.exceptions module](arpes.exceptions)
                  - [arpes.experiment module](arpes.experiment)
                  - [arpes.io module](arpes.io)
                  - [arpes.laser module](arpes.laser)
                  - [arpes.load\_pxt module](arpes.load_pxt)
                  - [arpes.optics module](arpes.optics)
                  - [arpes.pipeline module](arpes.pipeline)
                  - [arpes.pipelines module](arpes.pipelines)
                  - [arpes.provenance module](arpes.provenance)
                  - [arpes.repair module](arpes.repair)
                  - [arpes.simulation module](arpes.simulation)
                  - [arpes.typing module](arpes.typing)
                  - [arpes.widgets module](arpes.widgets)
                  - [arpes.xarray\_extensions
                    module](arpes.xarray_extensions)
                  - [arpes.xarray\_html\_repr
                    module](arpes.xarray_html_repr)
        
          - [Module contents](arpes#module-arpes)
